@@ -2,7 +2,7 @@ use crate::{
     evaluation::evaluation_types::ExtraExposureInfo,
     event_logging::{
         event_logger::ExposureTrigger,
-        exposure_sampling::EvtSamplingDecision,
+        exposure_sampling::{EvtSamplingDecision, ExposureSamplingKey},
         exposure_utils::{get_metadata_with_details, get_statsig_metadata_with_sampling_decision},
         statsig_event::StatsigEvent,
         statsig_event_internal::{StatsigEventInternal, CONFIG_EXPOSURE_EVENT_NAME},
@@ -48,21 +48,17 @@ impl EnqueueOperation for EnqueueExperimentExpoOp<'_> {
 }
 
 impl<'a> QueuedExposure<'a> for EnqueueExperimentExpoOp<'a> {
-    fn create_exposure_sampling_key(&self) -> String {
-        let mut sampling_key = String::from("n:");
-        sampling_key.push_str(&self.experiment.name);
-        sampling_key.push_str(";u:");
-        sampling_key.push_str(&self.user.user_ref.data.create_hash().to_string());
-        sampling_key.push_str(&self.experiment.rule_id);
-        sampling_key
-    }
+    fn create_exposure_sampling_key(&self) -> ExposureSamplingKey {
+        let user_data = &self.user.user_ref.data;
+        let evaluation = self.experiment.__evaluation.as_ref().map(|e| &e.base);
 
-    fn create_spec_sampling_key(&self) -> String {
-        let mut sampling_key = String::from("n:");
-        sampling_key.push_str(&self.experiment.name);
-        sampling_key.push_str(";r:");
-        sampling_key.push_str(&self.experiment.rule_id);
-        sampling_key
+        let in_experiment = self
+            .experiment
+            .__evaluation
+            .as_ref()
+            .is_some_and(|e| e.is_user_in_experiment == Some(true));
+
+        ExposureSamplingKey::new(evaluation, user_data.as_ref(), in_experiment as u64)
     }
 
     fn get_rule_id_ref(&self) -> &'a str {
