@@ -1,9 +1,6 @@
 use async_trait::async_trait;
 
-use crate::{
-    networking::{HttpMethod, NetworkProvider, RequestArgs, Response},
-    StatsigErr,
-};
+use crate::networking::{HttpMethod, NetworkProvider, RequestArgs, Response};
 
 pub struct NetworkProviderNoop;
 
@@ -17,8 +14,4 @@ impl NetworkProvider for NetworkProviderNoop {
             headers: None,
         }
     }
-
-    async fn shutdown(&self) -> Result<(), StatsigErr> {
-        Ok(())
-    }
 }
